@@ -21,9 +21,7 @@ import webob.exc
 from searchlight.api import policy
 from searchlight.common import wsgi
 import searchlight.context
-from searchlight import i18n
-
-_ = i18n._
+from searchlight.i18n import _
 
 context_opts = [
     cfg.BoolOpt('owner_is_tenant', default=True,
@@ -51,7 +49,7 @@ class BaseContextMiddleware(wsgi.Middleware):
         try:
             request_id = resp.request.context.request_id
         except AttributeError:
-            LOG.warn(_('Unable to retrieve request id from context'))
+            LOG.warning('Unable to retrieve request id from context')
         else:
             # For python 3 compatibility need to use bytes type
             prefix = 'req-'
@@ -85,6 +83,13 @@ class ContextMiddleware(BaseContextMiddleware):
         """
         if req.headers.get('X-Identity-Status') == 'Confirmed':
             req.context = self._get_authenticated_context(req)
+            # Don't allow domain-scoped tokens any further since it's not clear
+            # what access should be allowed
+            if not req.context.tenant:
+                raise webob.exc.HTTPUnauthorized(
+                    "No project/tenant found in the provided token (may be a "
+                    "domain-scoped token?). A project-scoped token must be "
+                    "provided.")
         elif CONF.allow_anonymous_access:
             req.context = self._get_anonymous_context()
         else:
@@ -119,16 +124,23 @@ class ContextMiddleware(BaseContextMiddleware):
                 raise webob.exc.HTTPInternalServerError(
                     _('Invalid service catalog json.'))
 
+        # TODO(sjmc7) consider changing this to use RequestContext.from_environ
+        # rather than parsing headers ourselves.
+        # Default this to true is the header's missing; older versions
+        # of oslo_context don't include it and some keystone configurations
+        # may not include it either. Look at defaulting to False in ocata
+        is_admin_project = req.headers.get('X-Is-Admin-Project',
+                                           'true').lower() == 'true'
         kwargs = {
             'user': req.headers.get('X-User-Id'),
             'tenant': req.headers.get('X-Tenant-Id'),
             'roles': roles,
-            'is_admin': CONF.admin_role.strip().lower() in roles,
             'auth_token': req.headers.get('X-Auth-Token', deprecated_token),
             'owner_is_tenant': CONF.owner_is_tenant,
             'service_catalog': service_catalog,
             'policy_enforcer': self.policy_enforcer,
             'request_id': req.headers.get('X-Openstack-Request-ID'),
+            'is_admin_project': is_admin_project
         }
 
         return searchlight.context.RequestContext(**kwargs)
