@@ -20,8 +20,6 @@ Routines for configuring Searchlight
 """
 
 import logging
-import logging.config
-import logging.handlers
 import os
 import tempfile
 
@@ -31,11 +29,9 @@ from oslo_middleware import cors
 from oslo_policy import policy
 from paste import deploy
 
-from searchlight import i18n
+from searchlight.i18n import _
 from searchlight.version import version_info as version
 
-_ = i18n._
-
 
 paste_deploy_opts = [
     cfg.StrOpt('flavor',
@@ -55,9 +51,10 @@ common_opts = [
     cfg.IntOpt('api_limit_max', default=1000,
                help=_('Maximum permissible number of items that could be '
                       'returned by a request')),
-    cfg.StrOpt('pydev_worker_debug_host',
-               help=_('The hostname/IP of the pydev process listening for '
-                      'debug connections')),
+    cfg.HostAddressOpt('pydev_worker_debug_host',
+                       help=_('The hostname/IP of the pydev '
+                              'process listening for '
+                              'debug connections')),
     cfg.IntOpt('pydev_worker_debug_port', default=5678,
                help=_('The port on which a pydev process is listening for '
                       'connections.')),
@@ -177,7 +174,7 @@ def set_config_defaults():
 def set_cors_middleware_defaults():
     """Update default configuration options for oslo.middleware."""
     # CORS Defaults
-    # TODO(krotscheck): Update with https://review.openstack.org/#/c/285368/
+    # TODO(krotscheck): Update with https://review.opendev.org/#/c/285368/
     cfg.set_defaults(cors.CORS_OPTS,
                      allow_headers=['X-Auth-Token',
                                     'X-OpenStack-Request-ID'],
