@@ -24,13 +24,11 @@ and spinning down the servers.
 import atexit
 import datetime
 import elasticsearch
-import httplib2
 import importlib
-import json
-import logging
-import mock
+import logging as std_logging
 import os
 import platform
+import requests
 import shutil
 import signal
 import six
@@ -38,10 +36,11 @@ import socket
 import sys
 import tempfile
 import time
+from unittest import mock
 
 import fixtures
+from oslo_log import log as logging
 from oslo_serialization import jsonutils
-# NOTE(jokke): simplified transition to py3, behaves like py2 xrange
 from six.moves import range
 from six.moves import urllib
 import testtools
@@ -51,6 +50,11 @@ from searchlight.elasticsearch.plugins import utils as es_utils
 from searchlight.tests import utils as test_utils
 
 
+LOG = logging.getLogger(__name__)
+tracer = std_logging.getLogger('elasticsearch.trace')
+tracer.setLevel(std_logging.INFO)
+tracer.addHandler(std_logging.NullHandler())
+
 execute, get_unused_port = test_utils.execute, test_utils.get_unused_port
 tracecmd_osmap = {'Linux': 'strace', 'FreeBSD': 'truss'}
 
@@ -214,7 +218,7 @@ class Server(object):
         return (rc, '', '')
 
     def dump_log(self, name):
-        log = logging.getLogger(name)
+        log = std_logging.getLogger(name)
         if not self.log_file or not os.path.exists(self.log_file):
             return
         fptr = open(self.log_file, 'r')
@@ -270,6 +274,7 @@ service_policy_path = %(service_policy_path)s
 workers = 0
 bind_host = 127.0.0.1
 bind_port = %(bind_port)s
+
 """
         self.paste_conf_base = """[pipeline:searchlight]
 pipeline = versionnegotiation unauthenticated-context rootapp
@@ -440,14 +445,14 @@ class FunctionalTest(test_utils.BaseTestCase):
 
         # Reproduce the logic from searchlight.common.utils to set up
         # parent/child relationships; the stevedore structure is different
-        for instance in six.itervalues(self.initialized_plugins):
+        for instance in self.initialized_plugins.values():
             parent_plugin_name = instance.parent_plugin_type()
             if parent_plugin_name:
                 parent_plugin = self.initialized_plugins[parent_plugin_name]
                 instance.register_parent(parent_plugin)
 
         # Reproduce the logic from cmd.manage to prepare the index.
-        for instance in six.itervalues(self.initialized_plugins):
+        for instance in self.initialized_plugins.values():
             instance.prepare_index(index_name=index_name)
 
         # Create the aliases
@@ -506,16 +511,16 @@ class FunctionalTest(test_utils.BaseTestCase):
             "headers": headers
         }
         if body:
-            kwargs["body"] = jsonutils.dumps(body)
+            kwargs["data"] = jsonutils.dumps(body)
 
-        http = httplib2.Http()
-        response, content = http.request(
-            self.base_url + uri,
+        response = requests.request(
             method,
+            self.base_url + uri,
             **kwargs
         )
+        content = response.content
         if decode_json:
-            content = jsonutils.loads(content)
+            content = response.json()
         return response, content
 
     def _search_request(self, body, tenant, role="member", decode_json=True,
@@ -563,41 +568,40 @@ class FunctionalTest(test_utils.BaseTestCase):
         index = ','.join(indices)
         es_url = "http://localhost:%s/%s/_search" % (
             self.api_server.elasticsearch_port, index)
-        response, content = httplib2.Http().request(es_url)
-        self.assertEqual(200, response.status)
-        return jsonutils.loads(content)
+        response = requests.get(es_url)
+        self.assertEqual(200, response.status_code)
+        return response.json()
 
     def _get_elasticsearch_doc(self, index_name, doc_type, doc_id):
         es_url = "http://localhost:%s/%s/%s/%s" % (
             self.api_server.elasticsearch_port, index_name, doc_type, doc_id)
 
-        response, content = httplib2.Http().request(es_url)
-        json_content = jsonutils.loads(content)
-        return json_content
+        response = requests.get(es_url)
+        return response.json()
 
     def _delete_elasticsearch_doc(self, index_name, doc_type, doc_id):
         es_url = "http://localhost:%s/%s/%s/%s" % (
             self.api_server.elasticsearch_port, index_name, doc_type, doc_id)
 
-        response, content = httplib2.Http().request(es_url, "DELETE")
-        json_content = jsonutils.loads(content)
-        return json_content
+        response = requests.delete(es_url)
+        return response.json()
 
     def _get_elasticsearch_aliases(self, indices):
         """Return all aliases associated with a specified index(es). The
-           caller can specify a list of indcies. If the list is empty, we
+           caller can specify a list of indices. If the list is empty, we
            will query all indices.
         """
         index = ','.join(indices)
         es_url = "http://localhost:%s/%s/_aliases" % (
             self.api_server.elasticsearch_port, index)
-        response, content = httplib2.Http().request(es_url)
-        return jsonutils.loads(content)
+        response = requests.get(es_url)
+        return response.json()
 
     def _load_fixture_data(self, name):
         base_dir = "searchlight/tests/functional/data"
-        with open(os.path.join(base_dir, name), 'r') as f:
-            return json.load(f)
+        # binary mode is needed due to bug/1515231
+        with open(os.path.join(base_dir, name), 'r+b') as f:
+            return jsonutils.load(f)
 
     def set_policy_rules(self, rules):
         fap = open(self.policy_file, 'w')
@@ -727,7 +731,7 @@ class FunctionalTest(test_utils.BaseTestCase):
         :param servers: Searchlight server ports to ping
         :param expect_launch: Optional, true iff the server(s) are
                               expected to successfully start
-        :param timeout: Optional, defaults to 3 seconds
+        :param timeout: Optional, defaults to 10 seconds
         :return: None if launch expectation is met, otherwise an
                  assertion message
         """
@@ -840,11 +844,10 @@ class ElasticsearchWrapper(object):
         }
         # Set JVM options
         exec_env = {
-            'ES_HEAP_SIZE': '50m'
+            'ES_HEAP_SIZE': '64m'
         }
         cmd = 'elasticsearch '
-        cmd += ' '.join('--%s=%s' % kv for kv in six.iteritems(es_options))
-
+        cmd += ' '.join('--%s=%s' % kv for kv in es_options.items())
         # Fork and retain the PID
         self.elasticsearch_pid = test_utils.fork_exec(cmd,
                                                       logfile=os.devnull,
@@ -865,17 +868,16 @@ class ElasticsearchWrapper(object):
         atexit.register(_stop_elasticsearch)
 
         # Wait for elasticsearch to spin up; it takes a while to initialize
-        http = httplib2.Http()
         es_url = 'http://localhost:%s' % self.elasticsearch_port
-        for _ in range(6):
+        time.sleep(10)
+        for _ in range(10):
             try:
-                response, content = http.request(es_url)
-                if response.status == 200:
+                response = requests.get(es_url)
+                if response.status_code == 200:
                     break
-            except socket.error:
-                # Expect 'connection refused' a couple of times
-                pass
-            time.sleep(5)
+            except requests.exceptions.RequestException as e:
+                LOG.debug("ES startup: Request Exception occured: %s" % e)
+            time.sleep(10)
         else:
             raise Exception("Elasticsearch failed to start")
 
