@@ -13,22 +13,23 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-import json
-import mock
 import os
 import six
 import time
-import uuid
+from unittest import mock
+
+from oslo_serialization import jsonutils
+from oslo_utils import uuidutils
 
 from searchlight.elasticsearch import ROLE_USER_FIELD
 from searchlight.tests import functional
 from searchlight.tests import utils as test_utils
 
-TENANT1 = str(uuid.uuid4())
-TENANT2 = str(uuid.uuid4())
-TENANT3 = str(uuid.uuid4())
+TENANT1 = uuidutils.generate_uuid()
+TENANT2 = uuidutils.generate_uuid()
+TENANT3 = uuidutils.generate_uuid()
 
-USER1 = str(uuid.uuid4())
+USER1 = uuidutils.generate_uuid()
 
 fake_version_list = [test_utils.FakeVersion('2.1'),
                      test_utils.FakeVersion('2.1')]
@@ -47,13 +48,13 @@ class TestSearchApi(functional.FunctionalTest):
     it can use plugins for the sake of making requests
     """
     def _modify_policy_file(self, rules):
-        with open(self.policy_file, 'r') as policy_file:
-            existing_policy = json.load(policy_file)
+        with open(self.policy_file, 'r+b') as policy_file:
+            existing_policy = jsonutils.load(policy_file)
 
         existing_policy.update(rules)
 
         with open(self.policy_file, 'w') as policy_file:
-            json.dump(existing_policy, policy_file)
+            jsonutils.dump(existing_policy, policy_file)
 
         time.sleep(2)
 
@@ -65,7 +66,7 @@ class TestSearchApi(functional.FunctionalTest):
         things are working.
         """
         images_plugin = self.initialized_plugins['OS::Glance::Image']
-        doc_id = str(uuid.uuid4())
+        doc_id = uuidutils.generate_uuid()
         doc = {
             "owner": TENANT1,
             "visibility": "public",
@@ -94,7 +95,7 @@ class TestSearchApi(functional.FunctionalTest):
     def test_empty_results(self):
         """Test an empty dataset gets empty results."""
         response, json_content = self._search_request(MATCH_ALL, TENANT1)
-        self.assertEqual(200, response.status)
+        self.assertEqual(200, response.status_code)
         self.assertEqual([], self._get_hit_source(json_content))
 
     def test_nested_objects(self):
@@ -192,7 +193,7 @@ class TestSearchApi(functional.FunctionalTest):
 
     def test_query_none(self):
         """Test search when query is not specified"""
-        id_1 = str(uuid.uuid4())
+        id_1 = uuidutils.generate_uuid()
         tenant1_doc = {
             "owner": TENANT1,
             "id": id_1,
@@ -206,13 +207,13 @@ class TestSearchApi(functional.FunctionalTest):
 
         response, json_content = self._search_request({"all_projects": True},
                                                       TENANT1)
-        self.assertEqual(200, response.status)
+        self.assertEqual(200, response.status_code)
         tenant1_doc["members"] = []
         tenant1_doc["project_id"] = tenant1_doc["owner"]
         self.assertEqual([tenant1_doc], self._get_hit_source(json_content))
 
     def test_facet_exclude_fields(self):
-        id_1 = str(uuid.uuid4())
+        id_1 = uuidutils.generate_uuid()
         tenant1_doc = {
             "owner": TENANT1,
             "id": id_1,
@@ -228,7 +229,7 @@ class TestSearchApi(functional.FunctionalTest):
             TENANT1,
             include_fields=False,
             doc_type="OS::Nova::Server")
-        self.assertEqual(200, response.status)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(set(["doc_count"]),
                          set(six.iterkeys(json_content["OS::Nova::Server"])))
         self.assertEqual(0, json_content["OS::Nova::Server"]["doc_count"])
@@ -242,7 +243,7 @@ class TestSearchApi(functional.FunctionalTest):
     def test_facet_rbac(self):
         tenant1_doc = {
             "owner": TENANT1,
-            "id": str(uuid.uuid4()),
+            "id": uuidutils.generate_uuid(),
             "visibility": "private",
             "name": "owned by tenant 1",
             "container_format": "not-shown",
@@ -250,7 +251,7 @@ class TestSearchApi(functional.FunctionalTest):
         }
         tenant2_doc = {
             "owner": TENANT2,
-            "id": str(uuid.uuid4()),
+            "id": uuidutils.generate_uuid(),
             "visibility": "private",
             "name": "owned by tenant 1",
             "container_format": "shown",
@@ -328,8 +329,8 @@ class TestSearchApi(functional.FunctionalTest):
         expected = {
             u'name': u'status',
             u'options': [
-                {u'doc_count': 2, u'key': u'ACTIVE'},
-                {u'doc_count': 1, u'key': u'RESUMING'},
+                {u'doc_count': 2, u'key': u'active'},
+                {u'doc_count': 1, u'key': u'resuming'},
             ],
             u'type': u'string'
         }
@@ -364,6 +365,55 @@ class TestSearchApi(functional.FunctionalTest):
             status_facet,
         )
 
+    def test_search_rbac(self):
+        servers_plugin = self.initialized_plugins['OS::Nova::Server']
+        server1 = {
+            u'addresses': {},
+            u'flavor': {u'id': u'1'},
+            u'id': u'6c41b4d1-f0fa-42d6-9d8d-e3b99695aa69',
+            u'image': {u'id': u'a'},
+            u'name': u'instance1',
+            u'status': u'ACTIVE',
+            u'tenant_id': TENANT1,
+            u'created_at': u'2016-04-06T12:48:18Z',
+            u'updated_at': u'2016-04-07T15:51:35Z',
+            u'user_id': u'27f4d76b-be62-4e4e-aa33bb11cc55'
+        }
+        server2 = {
+            u'addresses': {},
+            u'flavor': {u'id': u'1'},
+            u'id': u'08ca6c43-eea8-48d0-bbb2-30c50109d5d8',
+            u'image': {u'id': u'a'},
+            u'name': u'instance2',
+            u'status': u'RESUMING',
+            u'tenant_id': TENANT2,
+            u'created_at': u'2016-04-06T12:48:18Z',
+            u'updated_at': u'2016-04-07T15:51:35Z',
+            u'user_id': u'27f4d76b-be62-4e4e-aa33bb11cc55'
+        }
+
+        with mock.patch(nova_version_getter, return_value=fake_version_list):
+            self._index(
+                servers_plugin,
+                [test_utils.DictObj(**server1),
+                 test_utils.DictObj(**server2)])
+
+        response, json_content = self._search_request(
+            {"query": {"match_all": {}}, "type": "OS::Nova::Server"},
+            TENANT1,
+            role="member")
+        self.assertEqual(1, json_content['hits']['total'])
+        self.assertEqual(["6c41b4d1-f0fa-42d6-9d8d-e3b99695aa69"],
+                         [h["_source"]["id"]
+                          for h in json_content["hits"]["hits"]])
+
+        response, json_content = self._search_request(
+            {"query": {"match_all": {}}, "type": "OS::Nova::Server",
+             "all_projects": True},
+            TENANT1,
+            role="admin")
+        self.assertEqual(2, json_content['hits']['total'])
+
     def test_nested_facets(self):
         """Check facets for a nested field (networks.OS-EXT-IPS:type). We
         expect a single count per server matched, not per object in the
@@ -499,7 +549,7 @@ class TestSearchApi(functional.FunctionalTest):
         response, json_content = self._search_request(MATCH_ALL,
                                                       TENANT1,
                                                       role="admin")
-        self.assertEqual(200, response.status)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(1, len(json_content['hits']['hits']))
         hit = json_content['hits']['hits'][0]
         self.assertEqual(doc_id + "_ADMIN", hit['_id'])
@@ -512,11 +562,11 @@ class TestSearchApi(functional.FunctionalTest):
         response, json_content = self._search_request(MATCH_ALL,
                                                       TENANT1,
                                                       role="member")
-        self.assertEqual(200, response.status)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(1, len(json_content['hits']['hits']))
         hit = json_content['hits']['hits'][0]
         self.assertEqual(doc_id + "_USER", hit['_id'])
-        for k, v in six.iteritems(hit):
+        for k, v in hit.items():
             self.assertFalse(k.startswith('OS-EXT-SRV-ATTR:'),
                              'No protected attributes should be present')
 
@@ -562,7 +612,7 @@ class TestSearchApi(functional.FunctionalTest):
             response, json_content = self._search_request(full_query,
                                                           TENANT1,
                                                           role="admin")
-            self.assertEqual(200, response.status)
+            self.assertEqual(200, response.status_code)
             self.assertEqual(1, json_content['hits']['total'],
                              "No results for: %s" % query)
             self.assertEqual(doc_id + '_ADMIN',
@@ -572,7 +622,7 @@ class TestSearchApi(functional.FunctionalTest):
             response, json_content = self._search_request(full_query,
                                                           TENANT1,
                                                           role="user")
-            self.assertEqual(200, response.status)
+            self.assertEqual(200, response.status_code)
             self.assertEqual(0, json_content['hits']['total'])
 
         # Run the same queries against 'name'; should get results
@@ -587,7 +637,7 @@ class TestSearchApi(functional.FunctionalTest):
             response, json_content = self._search_request(full_query,
                                                           TENANT1,
                                                           role="user")
-            self.assertEqual(200, response.status)
+            self.assertEqual(200, response.status_code)
             self.assertEqual(1, json_content['hits']['total'],
                              "No results for: %s %s" % (query, json_content))
             self.assertEqual(doc_id + '_USER',
@@ -667,10 +717,10 @@ class TestSearchApi(functional.FunctionalTest):
             "POST", "/search", tenant_id, {"query": {"match_all": {}}},
             decode_json=False,
             extra_headers={"X-Domain-Id": domain_id})
-        self.assertEqual(401, response.status)
+        self.assertEqual(401, response.status_code)
 
     def test_search_version(self):
-        id_1 = str(uuid.uuid4())
+        id_1 = uuidutils.generate_uuid()
         tenant1_doc = {
             "owner": TENANT1,
             "id": id_1,
@@ -866,8 +916,8 @@ class TestSearchApi(functional.FunctionalTest):
                                                       role="admin",
                                                       decode_json=False)
         # TODO(sjmc7) Grr! https://bugs.launchpad.net/searchlight/+bug/1610398
-        self.assertNotEqual(200, response.status)
-        # self.assertEqual(403, response.status)
+        self.assertNotEqual(200, response.status_code)
+        # self.assertEqual(403, response.status_code)
 
     def test_aggregation_policy(self):
         query = {
@@ -885,12 +935,12 @@ class TestSearchApi(functional.FunctionalTest):
                                                       TENANT1,
                                                       role="member",
                                                       decode_json=False)
-        self.assertEqual(403, response.status)
+        self.assertEqual(403, response.status_code)
 
         response, json_content = self._search_request(query,
                                                       TENANT1,
                                                       role="admin")
-        self.assertEqual(200, response.status)
+        self.assertEqual(200, response.status_code)
 
         # Now let nobody use aggregations
         self._modify_policy_file({'search:query:aggregations': '!'})
@@ -899,13 +949,13 @@ class TestSearchApi(functional.FunctionalTest):
                                                       TENANT1,
                                                       role="member",
                                                       decode_json=False)
-        self.assertEqual(403, response.status)
+        self.assertEqual(403, response.status_code)
 
         response, json_content = self._search_request(query,
                                                       TENANT1,
                                                       role="admin",
                                                       decode_json=False)
-        self.assertEqual(403, response.status)
+        self.assertEqual(403, response.status_code)
 
     def test_is_admin_project(self):
         """The X-IS-ADMIN-PROJECT header is the current solution to the
@@ -917,6 +967,7 @@ class TestSearchApi(functional.FunctionalTest):
             u'id': 'abcdef',
             u'tenant_id': TENANT1,
             u'user_id': USER1,
+            u'status': 'ACTIVE',
             u'image': {u'id': u'a'},
             u'flavor': {u'id': u'1'},
             u'created_at': u'2016-04-07T15:49:35Z',
@@ -927,6 +978,7 @@ class TestSearchApi(functional.FunctionalTest):
             u'id': '12341234',
             u'tenant_id': TENANT2,
             u'user_id': USER1,
+            u'status': 'ACTIVE',
             u'image': {u'id': u'a'},
             u'flavor': {u'id': u'1'},
             u'created_at': u'2016-04-07T15:49:35Z',
@@ -973,7 +1025,7 @@ class TestSearchApi(functional.FunctionalTest):
 class TestServerServicePolicies(functional.FunctionalTest):
     def _write_policy_file(self, filename, rules):
         with open(os.path.join(self.conf_dir, filename), 'w') as pol_file:
-            json.dump(rules, pol_file)
+            jsonutils.dump(rules, pol_file)
 
     def _additional_server_config(self):
         """Create some service policy files"""
@@ -1004,7 +1056,7 @@ class TestServerServicePolicies(functional.FunctionalTest):
     def test_service_policy_facet(self):
         response, json_content = self._facet_request(TENANT1,
                                                      role="user")
-        self.assertEqual(200, response.status)
+        self.assertEqual(200, response.status_code)
         self.assertIn('OS::Nova::Server', json_content)
         self.assertIn('OS::Cinder::Volume', json_content)
         self.assertNotIn('OS::Glance::Image', json_content)
@@ -1013,7 +1065,7 @@ class TestServerServicePolicies(functional.FunctionalTest):
 
         response, json_content = self._facet_request(TENANT1,
                                                      role="admin")
-        self.assertEqual(200, response.status)
+        self.assertEqual(200, response.status_code)
         self.assertIn('OS::Nova::Server', json_content)
         self.assertIn('OS::Glance::Image', json_content)
         self.assertIn('OS::Cinder::Volume', json_content)
@@ -1062,7 +1114,7 @@ class TestServerServicePolicies(functional.FunctionalTest):
         response, json_content = self._search_request(MATCH_ALL,
                                                       TENANT1,
                                                       role="user")
-        self.assertEqual(200, response.status)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(2, json_content['hits']['total'])
         self.assertEqual(
             set([server_doc['id'], volume_doc['id']]),
@@ -1071,7 +1123,7 @@ class TestServerServicePolicies(functional.FunctionalTest):
         response, json_content = self._search_request(MATCH_ALL,
                                                       TENANT1,
                                                       role="admin")
-        self.assertEqual(200, response.status)
+        self.assertEqual(200, response.status_code)
         self.assertEqual(3, json_content['hits']['total'])
         self.assertEqual(
             set([server_doc['id'], image_doc['id'], volume_doc['id']]),
@@ -1083,4 +1135,4 @@ class TestServerServicePolicies(functional.FunctionalTest):
                                                       TENANT1,
                                                       role="user",
                                                       decode_json=False)
-        self.assertEqual(403, response.status)
+        self.assertEqual(403, response.status_code)
